==================================
Bioconvert contributing guidelines
==================================

The are different ways to contribute to **Bioconvert** project. You may find
a bug or want a new converter to be added. You may want to contribute directly
by adding a new converter or fixing a bug or fix the documentation. In any case,
all contributions are welcome.

Bug Reports and Feature Requests
----------------------------------

If you have encountered a problem with **Bioconvert** or would like to discuss about
new feature or idea, please submit it to the issue tracker on GitHub at https://github.com/biokit/bioconvert/issues .

For bug reports, you will be asked to provide a few information such as
the **Bioconvert** version, the output produced during the code execution.
If possible, please try to create a minimal piece of code that produces
the error and post it as well.

Contributions
-------------

pull requests
~~~~~~~~~~~~~

The recommended way for new contributors to submit code to **Bioconvert** is to fork
the repository on GitHub and then submit a pull request after committing the
changes. The **Bioconvert** core developes will then approve and merge the request 
into the main repository.

The contributed code will be **licensed under Bioconvert's license**,
https://github.com/biokit/bioconvert/blob/master/LICENSE 
If you did not write the code yourself, please make sure the existing
license is compatible and include the license information in the
contributed files, or obtain a permission from the original
author to relicense the contributed code.

For details about Guide lines and the framework to be used within **Bioconvert**, 
please see the Developer Guide on http://bioconvert.readthedocs.io
